@@ -154,7 +154,8 @@ npcdensbw.conbandwidth <-
         bwmethod = switch(bws$method,
           cv.ml = CBWM_CVML,
           cv.ls = CBWM_CVLS,
-          cv.ls.np = CBWM_NPLS),
+          cv.ls.np = CBWM_NPLS,
+          cv.ccdf = CBWM_CCDF),        
         xkerneval = switch(bws$cxkertype,
           gaussian = CKER_GAUSS + bws$cxkerorder/2 - 1,
           epanechnikov = CKER_EPAN + bws$cxkerorder/2 - 1,
